<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @since		1.0
 * @package    	Leadferno
 * @subpackage 	Leadferno/public
 */

class Leadferno_Public
{
	/**
	 * The ID of this plugin.
	 *
	 * @since     1.0
	 * @access    private
	 * @var       string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since     1.0
	 * @access    private
	 * @var       string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since     1.0
	 * @param     string    $plugin_name       The name of the plugin.
	 * @param     string    $version    The version of this plugin.
	 */
	public function __construct($plugin_name, $version)
	{
		$this->plugin_name = $plugin_name;
		$this->version = $version;
	}

	/**
	 * Add the leadferno script.
	 *
	 * @since     1.0
	 */
	public function leadferno_add_script()
	{
		if (!$leadboxes = $this->leadferno_get_leadboxes())
			return;

		$match = false;

		foreach ($leadboxes as $leadbox) {
			$meta = get_post_meta($leadbox);

			// Disabled
			if ($meta['leadbox-enable'][0] == 'no')
				continue;

			// All pages
			if ($meta['leadbox-display'][0] == '1') {
				$match = $leadbox;
				$bid = $meta['leadbox-bid'][0];
				$multi = ($meta['leadbox-type'][0] == 'multi') ? true : false;

				break;
			}

			// Include pages
			if ($meta['leadbox-display'][0] == '2') {
				$included = $meta['leadbox-pages'][0];
				$included = maybe_unserialize($included);

				if (!empty($included) && is_page()) {
					$id = get_the_ID();

					if (in_array($id, $included)) {
						$match = $leadbox;
						$bid = $meta['leadbox-bid'][0];
						$multi = ($meta['leadbox-type'][0] == 'multi') ? true : false;

						break;
					}
				}

				$urls = $meta['leadbox-urls'][0];
				$urls = maybe_unserialize($urls);

				if (!empty($urls)) {
					global $wp;
					$current = $wp->request;

					foreach ($urls as $url) {
						$url = trim($url, '/');

						if (substr($current, 0, strlen($url)) === $url) {
							$match = $leadbox;
							$bid = $meta['leadbox-bid'][0];
							$multi = ($meta['leadbox-type'][0] == 'multi') ? true : false;

							break 2;
						}
					}
				}
			}

			// Exclude pages
			if ($meta['leadbox-display'][0] == '-2') {
				$excluded = $meta['leadbox-pages'][0];
				$excluded = maybe_unserialize($excluded);

				if (!empty($excluded) && is_page()) {
					$id = get_the_ID();

					if (in_array($id, $excluded))
						break;
				}

				$urls = $meta['leadbox-urls'][0];
				$urls = maybe_unserialize($urls);

				if (!empty($urls)) {
					global $wp;
					$current = $wp->request;

					foreach ($urls as $url) {
						$url = trim($url, '/');

						if (substr($current, 0, strlen($url)) === $url) {
							break 2;
						}
					}
				}

				$match = $leadbox;
				$bid = $meta['leadbox-bid'][0];
				$multi = ($meta['leadbox-type'][0] == 'multi') ? true : false;

				break;
			}
		}

		if (!$match)
			return;

		$script = '<script src="https://widget.leadferno.com/leadbox.js" ';
		if ($multi)
			$script .= 'data-multi-profile ';
		$script .= 'data-leadferno data-bid="' . $bid . '" ';
		$script .= 'data-url="https://api.leadferno.com/v0"></script>';

		echo $script;
	}

	/**
	 * Get leadboxes ids.
	 *
	 * @since     1.0
	 */
	public function leadferno_get_leadboxes()
	{
		$args = array(
			'post_type' => 'leadbox',
			'post_status' => 'publish',
			'posts_per_page' => -1,
			'order' => 'DESC',
			'orderby' => 'date',
			'fields' => 'ids'
		);

		$leadboxes = get_posts($args);

		return $leadboxes;
	}
}
